<?php
session_start();

// Verificar si el usuario está autenticado
if (!isset($_SESSION['user_id'])) {
    http_response_code(401); // Unauthorized
    echo json_encode(['error' => 'User not authenticated']);
    exit();
}

// Datos del usuario
$user_id = $_SESSION['user_id'];

// Conexión a la base de datos
require_once 'config.php';

// Obtener conversaciones actualizadas del usuario
// (Misma consulta que en el dashboard original)
$chats_query = "
    SELECT 
        u.id, u.name, u.phone,
        (SELECT message FROM messages 
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?) 
         ORDER BY timestamp DESC LIMIT 1) as last_message,
        (SELECT timestamp FROM messages 
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?) 
         ORDER BY timestamp DESC LIMIT 1) as last_timestamp,
        (SELECT COUNT(*) FROM messages 
         WHERE sender_id = u.id AND receiver_id = ? AND `read` = 0) as unread_count
    FROM 
        users u
    WHERE 
        u.id != ? AND
        EXISTS (
            SELECT 1 FROM messages 
            WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?)
        )
    ORDER BY 
        last_timestamp DESC
";
$chats_stmt = $conn->prepare($chats_query);
// Asegúrate de que el número y tipo de 'i' coincidan exactamente con los '?' en la consulta
$chats_stmt->bind_param("iiiiiiii", $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id); 
$chats_stmt->execute();
$chats_result = $chats_stmt->get_result();
$chats = [];
while ($row = $chats_result->fetch_assoc()) {
    // Formatear timestamp aquí si es necesario antes de enviar JSON
    if ($row['last_timestamp']) {
        $ts = strtotime($row['last_timestamp']);
        if (date('Y-m-d', $ts) == date('Y-m-d')) {
            $row['formatted_timestamp'] = date('H:i', $ts);
        } else {
            $row['formatted_timestamp'] = date('d/m', $ts);
        }
    } else {
         $row['formatted_timestamp'] = '';
    }
    $chats[] = $row;
}

$chats_stmt->close();
$conn->close();

// Devolver los resultados como JSON
header('Content-Type: application/json');
echo json_encode($chats);
exit();
?>